@@ -106,3 +106,43 @@ def matlab_file_labchart(testpath):
 def matlab_file_acq(testpath):
     return fetch_file('mc96w', testpath,
                       'Test_belt_pulse_multifreq.mat')
+
+@pytest.fixture
+def ge_one_gep_file(testpath):
+    return fetch_file('wb84d', testpath,
+                      'PPGData_epiRT_0000000000_00_00_000.gep')
+
+@pytest.fixture
+def ge_two_gep_files_ppg(testpath):
+    tmp = fetch_file('qawjv', testpath,
+                     'RESPData_epiRT_0000000000_00_00_000.gep')
+    return fetch_file('wb84d', testpath,
+                      'PPGData_epiRT_0000000000_00_00_000.gep')
+
+@pytest.fixture
+def ge_two_gep_files_resp(testpath):
+    tmp = fetch_file('wb84d', testpath,
+                      'PPGData_epiRT_0000000000_00_00_000.gep')
+    return fetch_file('qawjv', testpath,
+                     'RESPData_epiRT_0000000000_00_00_000.gep')
+
+@pytest.fixture
+def ge_one_raw_file(testpath):
+    return fetch_file('u9wsr', testpath,
+                      'PPGData_epiRT_0000000000_00_00_000')
+
+@pytest.fixture
+def ge_two_raw_files(testpath):
+    tmp = fetch_file('49xpw', testpath,
+                     'RESPData_epiRT_0000000000_00_00_000')
+    return fetch_file('u9wsr', testpath,
+                      'PPGData_epiRT_0000000000_00_00_000')
+
+@pytest.fixture
+def ge_badfiles(testpath):
+    tmp = fetch_file('tdmyn', testpath,
+                     'PPGData_epiRT_columnscsv_00_00_000')
+    tmp = fetch_file('b6skq', testpath,
+                     'PPGData_epiRT_columnstsv_00_00_000')
+    return fetch_file('8235b', testpath,
+                      'PPGData_epiRT_string0000_00_00_000')
